@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2016 -- leonerd@leonerd.org.uk
 
 package Tickit::Widget::Scroller;
 
@@ -16,7 +16,7 @@ use Tickit::Window;
 use Tickit::Utils qw( textwidth );
 use Tickit::RenderBuffer;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use Carp;
 
@@ -113,7 +113,9 @@ Scroll to the bottom
 
 =cut
 
-=head2 $scroller = Tickit::Widget::Scroller->new( %args )
+=head2 new
+
+   $scroller = Tickit::Widget::Scroller->new( %args )
 
 Constructs a new C<Tickit::Widget::Scroller> object. The new object will start
 with an empty list of items.
@@ -237,8 +239,6 @@ sub window_gained
    my $self = shift;
    my ( $win ) = @_;
 
-   $win->set_expose_after_scroll( 1 );
-
    $self->{window_lines} = $win->lines;
 
    $self->SUPER::window_gained( $win );
@@ -248,14 +248,18 @@ sub window_gained
    }
 }
 
-=head2 $on_scrolled = $scroller->on_scrolled
+=head2 on_scrolled
 
-=head2 $scroller->set_on_scrolled( $on_scrolled )
+=head2 set_on_scrolled
+
+   $on_scrolled = $scroller->on_scrolled
+
+   $scroller->set_on_scrolled( $on_scrolled )
 
 Return or set the CODE reference to be called when the scroll position is
 adjusted.
 
- $on_scrolled->( $scroller, $delta )
+   $on_scrolled->( $scroller, $delta )
 
 This is invoked by the C<scroll> method, including the C<scroll_to>,
 C<scroll_to_top> and C<scroll_to_bottom>. In normal cases it will be given the
@@ -276,7 +280,9 @@ sub set_on_scrolled
    ( $self->{on_scrolled} ) = @_;
 }
 
-=head2 $scroller->push( @items )
+=head2 push
+
+   $scroller->push( @items )
 
 Append the given items to the end of the list.
 
@@ -335,7 +341,9 @@ sub push
    $self->update_indicators;
 }
 
-=head2 $scroller->unshift( @items )
+=head2 unshift
+
+   $scroller->unshift( @items )
 
 Prepend the given items to the beginning of the list.
 
@@ -404,7 +412,9 @@ sub unshift :method
    $self->update_indicators;
 }
 
-=head2 @items = $scroller->shift( $count )
+=head2 shift
+
+   @items = $scroller->shift( $count )
 
 Remove the given number of items from the start of the list and returns them.
 
@@ -450,7 +460,9 @@ sub shift :method
    return @ret;
 }
 
-=head2 @items = $scroller->pop( $count )
+=head2 pop
+
+   @items = $scroller->pop( $count )
 
 Remove the given number of items from the end of the list and returns them.
 
@@ -493,7 +505,9 @@ sub pop :method
    return @ret;
 }
 
-=head2 $scroller->scroll( $delta )
+=head2 scroll
+
+   $scroller->scroll( $delta )
 
 Move the display up or down by the given C<$delta> amount; with positive
 moving down. This will be a physical count of displayed lines; if some items
@@ -591,7 +605,9 @@ REDO:
    $self->update_indicators;
 }
 
-=head2 $scroller->scroll_to( $line, $itemidx, $itemline )
+=head2 scroll_to
+
+   $scroller->scroll_to( $line, $itemidx, $itemline )
 
 Moves the display up or down so that display line C<$line> contains line
 C<$itemline> of item C<$itemidx>. Any of these counts may be negative to count
@@ -675,7 +691,9 @@ sub scroll_to
    $self->scroll( $delta );
 }
 
-=head2 $scroller->scroll_to_top( $itemidx, $itemline )
+=head2 scroll_to_top
+
+   $scroller->scroll_to_top( $itemidx, $itemline )
 
 Shortcut for C<scroll_to> to set the top line of display; where C<$line> is 0.
 If C<$itemline> is undefined, it will be passed as 0. If C<$itemidx> is also
@@ -695,7 +713,9 @@ sub scroll_to_top
    $self->scroll_to( 0, $itemidx, $itemline );
 }
 
-=head2 $scroller->scroll_to_bottom( $itemidx, $itemline )
+=head2 scroll_to_bottom
+
+   $scroller->scroll_to_bottom( $itemidx, $itemline )
 
 Shortcut for C<scroll_to> to set the bottom line of display; where C<$line> is
 -1. If C<$itemline> is undefined, it will be passed as -1. If C<$itemidx> is
@@ -715,9 +735,11 @@ sub scroll_to_bottom
    $self->scroll_to( -1, $itemidx, $itemline );
 }
 
-=head2 $itemidx = $scroller->line2item( $line )
+=head2 line2item
 
-=head2 ( $itemidx, $itemline ) = $scroller->line2item( $line )
+   $itemidx = $scroller->line2item( $line )
+
+   ( $itemidx, $itemline ) = $scroller->line2item( $line )
 
 Returns the item index currently on display at the given line of the window.
 In list context, also returns the line number within item. If no window has
@@ -763,9 +785,11 @@ sub line2item
    return;
 }
 
-=head2 $line = $scroller->item2line( $itemidx, $itemline )
+=head2 item2line
 
-=head2 ( $line, $offscreen ) = $scroller->item2line( $itemidx, $itemline, $count_offscreen )
+   $line = $scroller->item2line( $itemidx, $itemline )
+
+   ( $line, $offscreen ) = $scroller->item2line( $itemidx, $itemline, $count_offscreen )
 
 Returns the display line in the window of the given line of the item at the
 given index. C<$itemidx> may be given negative, to count backwards from the
@@ -854,7 +878,9 @@ sub item2line
    return;
 }
 
-=head2 $count = $scroller->lines_above
+=head2 lines_above
+
+   $count = $scroller->lines_above
 
 Returns the number of lines of content above the scrolled display.
 
@@ -868,7 +894,9 @@ sub lines_above
    return -$line;
 }
 
-=head2 $count = $scroller->lines_below
+=head2 lines_below
+
+   $count = $scroller->lines_below
 
 Returns the number of lines of content below the scrolled display.
 
@@ -994,9 +1022,13 @@ sub on_mouse
    $self->scroll( -5 ) if $ev->button eq "up";
 }
 
-=head2 $scroller->set_gen_top_indicator( $method )
+=head2 set_gen_top_indicator
 
-=head2 $scroller->set_gen_bottom_indicator( $method )
+=head2 set_gen_bottom_indicator
+
+   $scroller->set_gen_top_indicator( $method )
+
+   $scroller->set_gen_bottom_indicator( $method )
 
 Accessors for the generators for the top and bottom indicator text. If set,
 each should be a CODE reference or method name on the scroller which will be
@@ -1006,7 +1038,7 @@ if defined and non-empty, will be displayed in an indicator window. This will
 be a small one-line window displayed at the top right or bottom right corner
 of the Scroller's window.
 
- $text = $scroller->$method()
+   $text = $scroller->$method()
 
 The ability to pass method names allows subclasses to easily implement custom
 logic as methods without having to capture a closure.
@@ -1029,7 +1061,9 @@ sub set_gen_bottom_indicator
    $self->update_indicators;
 }
 
-=head2 $scroller->update_indicators
+=head2 update_indicators
+
+   $scroller->update_indicators
 
 Calls any defined generators for indicator text, and updates the indicator
 windows with the returned text. This may be useful if the functions would
