@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2011-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2016 -- leonerd@leonerd.org.uk
 
 package Tickit::Widget::Scroller::Item::Text;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 use Tickit::Utils qw( textwidth cols2chars );
 
@@ -39,7 +39,9 @@ the C</\s/> regexp pattern).
 
 =cut
 
-=head2 $item = Tickit::Widget::Scroller::Item::Text->new( $text, %opts )
+=head2 new
+
+   $item = Tickit::Widget::Scroller::Item::Text->new( $text, %opts )
 
 Constructs a new text item, containing the given string of text. Once
 constructed, the item is immutable.
@@ -77,13 +79,15 @@ sub new
 
 =cut
 
-=head2 @chunks = $item->chunks
+=head2 chunks
+
+   @chunks = $item->chunks
 
 Returns the chunks of text displayed by this item. Each chunk is represented
 by an ARRAY reference of three fields, giving the text string, its width in
 columns, and various options
 
- [ $text, $width, %opts ]
+   [ $text, $width, %opts ]
 
 Recognised options are:
 
